@@ -142,13 +142,14 @@ class BindingContext(object):
         """A :class:`~binalyzer.template.Template` that is bound to the
         corresponding binary :attr:`~binalyzer.Binalyzer.data`.
         """
-        return self._create_dom()
+        self.template_provider.template = self._create_dom()
+        return self.template_provider.template
 
     @template.setter
     def template(self, value):
         self.template_provider.template = value
         self.template_provider.template.binding_context = self
-        self._invalidate_dom()
+        self.invalidate()
 
     @property
     def data(self):
@@ -166,7 +167,7 @@ class BindingContext(object):
             for child in template.children:
                 child.binding_context = self
 
-    def _invalidate_dom(self):
+    def invalidate(self):
         self._cached_dom = None
 
     def _create_dom(self):
